#include <chronoptics/tof/csf_writer.hpp>
#include <chronoptics/tof/kea_camera.hpp>
#include <iostream>

namespace tof = chronoptics::tof;

int main() {
  /* Number of frames to capture */
  const int numFrames = 10;

  /* Number of frames to drop before capturing */
  const int dropFrames = 100;

  /* Filename to save to */
  const char* filename = "frames_compare.csf";

  /* Serial number of the camera to connect to. If this is empty, the
     first camera that is found will be connected to */
  const char* serial = "2020004";

  /* Config file to use. If the config file can't be found then a
     default one will be used */
  const char* configFile = "";

  /* Frame types to capture */
  const std::vector<tof::FrameType> types = {tof::FrameType::RAW,
                                             tof::FrameType::RADIAL};

  tof::ProcessingConfig config(configFile);

  tof::KeaCamera cam(config, serial);
  tof::select_streams(cam, types);

  tof::CsfWriter writer = tof::create_csf_writer_camera(filename, cam);

  cam.start();

  /* Drop frames */
  for (int i = 0; i < dropFrames; i++) {
    cam.get_frames();
  }

  std::cout << "Frames dropped" << std::endl;

  /* Capture frames */
  for (int i = 0; i < numFrames; i++) {
    std::vector<tof::Data> frames = cam.get_frames();

    for (tof::Data& frame : frames) {
      writer.write_frame(frame);
    }
  }

  std::cout << "Frames captured" << std::endl;
}
